summaryrefslogtreecommitdiffstats
path: root/kmail/interfaces/bodyparturlhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/interfaces/bodyparturlhandler.h')
-rw-r--r--kmail/interfaces/bodyparturlhandler.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmail/interfaces/bodyparturlhandler.h b/kmail/interfaces/bodyparturlhandler.h
index 1fd8b16d..5dff819e 100644
--- a/kmail/interfaces/bodyparturlhandler.h
+++ b/kmail/interfaces/bodyparturlhandler.h
@@ -57,7 +57,7 @@ namespace KMail {
* URLHandler.
*
* You can create a link whose handling is passed to this handler
* by using BodyPart::makeLink( const QString & path ). \a path is
* what * is passed back to the methods of this interface.
*
* Note that the BodyPart interface does not provide a means of
@@ -77,7 +77,7 @@ namespace KMail {
@return true if the click was handled by this handler, false
otherwise.
*/
- virtual bool handleClick( BodyPart * part, const QString & path, Callback& c ) const = 0;
+ virtual bool handleClick( BodyPart * part, const TQString & path, Callback& c ) const = 0;
/** Called when RMB-clicking on a link in the reader. Should
show a context menu at the specified point with the
@@ -86,15 +86,15 @@ namespace KMail {
@return true if the right-click was handled by this handler,
false otherwise.
*/
- virtual bool handleContextMenuRequest( BodyPart * part, const QString & path, const QPoint & p ) const = 0;
+ virtual bool handleContextMenuRequest( BodyPart * part, const TQString & path, const TQPoint & p ) const = 0;
/** Called when hovering over a link.
@return a string to be shown in the status bar while
- hovering over this link or QString::null if the link was not
+ hovering over this link or TQString::null if the link was not
handled by this handler.
*/
- virtual QString statusBarMessage( BodyPart * part, const QString & path ) const = 0;
+ virtual TQString statusBarMessage( BodyPart * part, const TQString & path ) const = 0;
};
} // namespace Interface
@@ -57,7 +57,7 @@ namespace KMail {
*
* You can create a link whose handling is passed to this handler
- * by using BodyPart::makeLink( const QString & path ). \a path is
+ * by using BodyPart::makeLink( const TQString & path ). \a path is
* what * is passed back to the methods of this interface.
*